package crs

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Cr_comment.FilterSource

A type to select only a subset of CRs.

Sourcetype t =
  1. | All
  2. | Invalid
  3. | CRs
  4. | XCRs
  5. | Now
  6. | Soon
  7. | Someday
include Ppx_compare_lib.Comparable.S with type t := t
Sourceval compare : t -> t -> int
include Ppx_compare_lib.Equal.S with type t := t
Sourceval equal : t -> t -> bool
include Ppx_enumerate_lib.Enumerable.S with type t := t
Sourceval all : t list
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t

Representation

Sourceval to_string : t -> Base.string

A lowercase version of t for use e.g. as command line flags.

Sourceval shorthand : t -> Base.char

This defines opinionated shorthands to designate each case, to be used in UIs. May be shared by cli, editor integration, etc.

Matching

Sourceval matches : t -> cr:Cr_comment__.Cr_comment0.t -> Base.bool

Returns true iif the filter applies to the supplied CR.