package crs

  1. Overview
  2. Docs
On This Page
  1. Deprecated
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Cr_comment.HeaderSource

Sourcetype t
Sourceval equal : t -> t -> bool
Sourceval to_dyn : t -> Crs_stdlib.Dyn.t
Sourceval reporter : t -> User_handle.t

reporter is user in CR user....

Sourceval recipient : t -> User_handle.t option

recipient is user2 in CR user1 for user2: .... Assigning CRs to particular users is optional. This returns None if that part is left out, such as in CR user1: Comment.

Sourceval status : t -> Status.t
Sourceval qualifier : t -> Qualifier.t

This returns the qualifier if present (Soon for CR-soon or Someday for CR-someday). If there is no qualifier specified, this returns None.

Sourceval priority : t -> Priority.t

priority t represents the expectation as to when work on the CR is meant to happen. It is based on the header's qualifier except that XCRs are meant to be worked on Now.

Sourcemodule With_loc : sig ... end

These getters allows you to access the position of each elements of the CR header. This is meant for tools processing CRs automatically, such as CRs rewriters.

Deprecated

The following is deprecated. Please migrate, and do not use in new code.

Sourceval reported_by : t -> User_handle.t

This was renamed reporter. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.reporter]. Hint: Run [ocamlmig migrate]
Sourceval for_ : t -> User_handle.t option

This was renamed recipient. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.recipient]. Hint: Run [ocamlmig migrate]
Sourceval kind : t -> Status.t

This was renamed status. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.status]. Hint: Run [ocamlmig migrate]