package crs

  1. Overview
  2. Docs
On This Page
  1. Deprecated
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Header.With_locSource

These getters allows you to access the position of each elements of the CR header. This is meant for tools processing CRs automatically, such as CRs rewriters.

Sourceval reporter : t -> User_handle.t Loc.Txt.t

The location includes the entire reporter username, without the surrounding spaces.

Sourceval recipient : t -> User_handle.t Loc.Txt.t option

The location includes the entire recipient username, if it is present, without the surrounding spaces. In particular, the location does not include the "for" keyword itself.

Sourceval status : t -> Status.t Loc.Txt.t

The location includes the entire keyword "CR" or "XCR" depending on the case. It stops right before the following char, that being a space or a '-' (and thus does not include it).

Sourceval qualifier : t -> Qualifier.t Loc.Txt.t

When the CR is qualified as Soon or Someday, the location returned starts right after the dash separator (but does not include it), and contains the entire qualifier keyword. For example, the location will include "soon" for a CR-soon. When the CR has no qualifier, there is no keyword to attach a location to : conventionally, we return instead the location of the CR status in this case.

Deprecated

The following is deprecated. Please migrate, and do not use in new code.

Sourceval kind : t -> Status.t Loc.Txt.t

This was renamed status. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.With_loc.status]. Hint: Run [ocamlmig migrate]
Sourceval reported_by : t -> User_handle.t Loc.Txt.t

This was renamed reporter. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.With_loc.reporter]. Hint: Run [ocamlmig migrate]
Sourceval for_ : t -> User_handle.t Loc.Txt.t option

This was renamed recipient. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.With_loc.recipient]. Hint: Run [ocamlmig migrate]

This was renamed qualifier. Hint: Run ocamlmig migrate.

  • deprecated [since 2025-10] Use [Header.With_loc.qualifier]. Hint: Run [ocamlmig migrate]