package crs

  1. Overview
  2. Docs
On This Page
  1. Serialize
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Std.Github_annotationSource

GitHub Annotations are created when encountering special log lines produced by actions during workflow executions.

Examples:

 ::notice file={name},line={line},endLine={endLine},title={title}::{message}
 ::warning file={name},line={line},endLine={endLine},title={title}::{message}

This module allow creating and producing workflow commands that can create annotations.

Sourcemodule Severity : sig ... end
Sourcetype t
Sourceval to_dyn : t -> Crs_stdlib.Dyn.t
Sourceval create : loc:Loc.t -> severity:Severity.t -> title:string -> message:string -> t

Serialize

Sourceval to_string : t -> string

Create the syntax to be produced by log lines, without the trailing "\n".