package crs

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file qualifier.ml

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
(********************************************************************************)
(*  crs - A tool for managing inline review comments embedded in source code    *)
(*  Copyright (C) 2024-2026 Mathieu Barbin <mathieu.barbin@gmail.com>           *)
(*                                                                              *)
(*  This file is part of crs.                                                   *)
(*                                                                              *)
(*  crs is free software; you can redistribute it and/or modify it under the    *)
(*  terms of the GNU Lesser General Public License as published by the Free     *)
(*  Software Foundation either version 3 of the License, or any later version,  *)
(*  with the LGPL-3.0 Linking Exception.                                        *)
(*                                                                              *)
(*  crs is distributed in the hope that it will be useful, but WITHOUT ANY      *)
(*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS   *)
(*  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License and     *)
(*  the file `NOTICE.md` at the root of this repository for more details.       *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  and the LGPL-3.0 Linking Exception along with this library. If not, see     *)
(*  <http://www.gnu.org/licenses/> and <https://spdx.org>, respectively.        *)
(********************************************************************************)

type t =
  | None
  | Soon
  | Someday

let variant_constructor_rank = function
  | None -> 0
  | Soon -> 1
  | Someday -> 2
;;

let compare t1 t2 =
  Int.compare (variant_constructor_rank t1) (variant_constructor_rank t2)
;;

let equal t1 t2 = Int.equal (variant_constructor_rank t1) (variant_constructor_rank t2)
let all = [ None; Soon; Someday ]

let variant_constructor_name = function
  | None -> "None"
  | Soon -> "Soon"
  | Someday -> "Someday"
;;

let to_dyn t = Dyn.Variant (variant_constructor_name t, [])

let priority : t -> Priority.t = function
  | None -> Now
  | Soon -> Soon
  | Someday -> Someday
;;